@@ -1,46 +1,33 @@
-import threading
+from typing import Optional
 
-from pydantic import BaseModel
+from pydantic.v1 import BaseModel
 
 from prowler.lib.logger import logger
 from prowler.lib.scan_filters.scan_filters import is_resource_filtered
-from prowler.providers.aws.aws_provider import generate_regional_clients
+from prowler.providers.aws.lib.service.service import AWSService
 
 
-################################ EKS
-class EKS:
-    def __init__(self, audit_info):
-        self.service = "eks"
-        self.session = audit_info.audit_session
-        self.audit_resources = audit_info.audit_resources
-        self.regional_clients = generate_regional_clients(self.service, audit_info)
+class EKS(AWSService):
+    def __init__(self, provider):
+        # Call AWSService's __init__
+        super().__init__(__class__.__name__, provider)
         self.clusters = []
-        self.__threading_call__(self.__list_clusters__)
-        self.__describe_cluster__(self.regional_clients)
+        self.__threading_call__(self._list_clusters)
+        self._describe_cluster(self.regional_clients)
 
-    def __get_session__(self):
-        return self.session
-
-    def __threading_call__(self, call):
-        threads = []
-        for regional_client in self.regional_clients.values():
-            threads.append(threading.Thread(target=call, args=(regional_client,)))
-        for t in threads:
-            t.start()
-        for t in threads:
-            t.join()
-
-    def __list_clusters__(self, regional_client):
+    def _list_clusters(self, regional_client):
         logger.info("EKS listing clusters...")
         try:
             list_clusters_paginator = regional_client.get_paginator("list_clusters")
             for page in list_clusters_paginator.paginate():
                 for cluster in page["clusters"]:
+                    arn = f"arn:{self.audited_partition}:eks:{regional_client.region}:{self.audited_account}:cluster/{cluster}"
                     if not self.audit_resources or (
-                        is_resource_filtered(cluster, self.audit_resources)
+                        is_resource_filtered(arn, self.audit_resources)
                     ):
                         self.clusters.append(
                             EKSCluster(
+                                arn=arn,
                                 name=cluster,
                                 region=regional_client.region,
                             )
@@ -51,13 +38,12 @@ class EKS:
                 f"{regional_client.region} -- {error.__class__.__name__}[{error.__traceback__.tb_lineno}]: {error}"
             )
 
-    def __describe_cluster__(self, regional_clients):
+    def _describe_cluster(self, regional_clients):
         logger.info("EKS listing clusters...")
         try:
             for cluster in self.clusters:
                 regional_client = regional_clients[cluster.region]
                 describe_cluster = regional_client.describe_cluster(name=cluster.name)
-                cluster.arn = describe_cluster["cluster"]["arn"]
                 if "logging" in describe_cluster["cluster"]:
                     cluster.logging = EKSClusterLoggingEntity(
                         types=describe_cluster["cluster"]["logging"]["clusterLogging"][
@@ -67,6 +53,13 @@ class EKS:
                             "clusterLogging"
                         ][0]["enabled"],
                     )
+                if (
+                    "clusterSecurityGroupId"
+                    in describe_cluster["cluster"]["resourcesVpcConfig"]
+                ):
+                    cluster.security_group_id = describe_cluster["cluster"][
+                        "resourcesVpcConfig"
+                    ]["clusterSecurityGroupId"]
                 if (
                     "endpointPublicAccess"
                     in describe_cluster["cluster"]["resourcesVpcConfig"]
@@ -90,6 +83,8 @@ class EKS:
                     ]["publicAccessCidrs"]
                 if "encryptionConfig" in describe_cluster["cluster"]:
                     cluster.encryptionConfig = True
+                cluster.tags = [describe_cluster["cluster"].get("tags")]
+                cluster.version = describe_cluster["cluster"].get("version", "")
 
         except Exception as error:
             logger.error(
@@ -104,10 +99,13 @@ class EKSClusterLoggingEntity(BaseModel):
 
 class EKSCluster(BaseModel):
     name: str
-    arn: str = None
+    arn: str
     region: str
+    version: str = None
     logging: EKSClusterLoggingEntity = None
+    security_group_id: str = None
     endpoint_public_access: bool = None
     endpoint_private_access: bool = None
-    public_access_cidrs: list[str] = None
+    public_access_cidrs: list[str] = []
     encryptionConfig: bool = None
+    tags: Optional[list] = []
