@@ -9,10 +9,15 @@ class iam_user_two_active_access_key(Check):
             findings = []
             response = iam_client.credential_report
             for user in response:
-                report = Check_Report_AWS(self.metadata())
+                report = Check_Report_AWS(metadata=self.metadata(), resource=user)
                 report.resource_id = user["user"]
                 report.resource_arn = user["arn"]
                 report.region = iam_client.region
+                # Search user in iam_client.users to get tags
+                for iam_user in iam_client.users:
+                    if iam_user.arn == user["arn"]:
+                        report.resource_tags = iam_user.tags
+                        break
                 if (
                     user["access_key_1_active"] == "true"
                     and user["access_key_2_active"] == "true"
@@ -24,7 +29,7 @@ class iam_user_two_active_access_key(Check):
                 else:
                     report.status = "PASS"
                     report.status_extended = (
-                        f"User {user['user']} has not 2 active access keys."
+                        f"User {user['user']} does not have 2 active access keys."
                     )
                 findings.append(report)
         except Exception as error:
