@@ -6,15 +6,12 @@ class sns_topics_kms_encryption_at_rest_enabled(Check):
     def execute(self):
         findings = []
         for topic in sns_client.topics:
-            report = Check_Report_AWS(self.metadata())
-            report.region = topic.region
-            report.resource_id = topic.name
-            report.resource_arn = topic.arn
+            report = Check_Report_AWS(metadata=self.metadata(), resource=topic)
             report.status = "PASS"
-            report.status_extended = f"SNS topic {topic.arn} is encrypted"
+            report.status_extended = f"SNS topic {topic.name} is encrypted."
             if not topic.kms_master_key_id:
                 report.status = "FAIL"
-                report.status_extended = f"SNS topic {topic.arn} is not encrypted"
+                report.status_extended = f"SNS topic {topic.name} is not encrypted."
 
             findings.append(report)
 
