@@ -7,15 +7,15 @@ class storage_secure_transfer_required_is_enabled(Check):
         findings = []
         for subscription, storage_accounts in storage_client.storage_accounts.items():
             for storage_account in storage_accounts:
-                report = Check_Report_Azure(self.metadata())
+                report = Check_Report_Azure(
+                    metadata=self.metadata(), resource=storage_account
+                )
                 report.subscription = subscription
                 report.status = "PASS"
-                report.status_extended = f"Storage account {storage_account.name} from subscription {subscription} has secure transfer required enabled"
-                report.resource_name = storage_account.name
-                report.resource_id = storage_account.id
+                report.status_extended = f"Storage account {storage_account.name} from subscription {subscription} has secure transfer required enabled."
                 if not storage_account.enable_https_traffic_only:
                     report.status = "FAIL"
-                    report.status_extended = f"Storage account {storage_account.name} from subscription {subscription} has secure transfer required disabled"
+                    report.status_extended = f"Storage account {storage_account.name} from subscription {subscription} has secure transfer required disabled."
 
                 findings.append(report)
 
